import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{f as t,q as n}from"./vendor-primevue-7po8Zk9v.js";import{$ as r,D as i,F as a,Ft as o,L as s,Lt as c,O as l,ht as u,nt as d}from"./vendor-vue-core-D3IvUUeM.js";var f={class:`flex h-full w-full flex-col gap-2`},p=s({__name:`PanelTemplate`,props:{value:{},class:{}},setup(e){let s=e;return(e,p)=>(r(),l(o(t),{value:s.value,class:c([`h-full w-full`,s.class])},{default:u(()=>[i(`div`,f,[d(e.$slots,`header`),a(o(n),{class:`h-0 grow pr-2`},{default:u(()=>[d(e.$slots,`default`)]),_:3}),d(e.$slots,`footer`)])]),_:3},8,[`value`,`class`]))}});export{p as t};
//# sourceMappingURL=PanelTemplate-CuvxTtdx.js.map