import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{t}from"./vendor-primevue-7po8Zk9v.js";import{$ as n,A as r,D as i,E as a,F as o,Ft as s,L as c,W as l,lt as u}from"./vendor-vue-core-D3IvUUeM.js";var d={class:`flex flex-col gap-1`},f={class:`max-h-[48rem] rounded border p-4`},p=c({__name:`WidgetChart`,props:l({widget:{}},{modelValue:{required:!0},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let c=u(e,`modelValue`),l=e,p=a(()=>l.widget.options?.type??`line`),m=a(()=>c.value||{labels:[],datasets:[]}),h=a(()=>({responsive:!0,maintainAspectRatio:!1,plugins:{legend:{labels:{color:`#FFF`,usePointStyle:!0,pointStyle:`circle`}}},scales:{x:{ticks:{color:`#9FA2BD`},grid:{display:!0,color:`#9FA2BD`,drawTicks:!1,drawOnChartArea:!0,drawBorder:!1},border:{display:!0,color:`#9FA2BD`}},y:{ticks:{color:`#9FA2BD`},grid:{display:!1,drawTicks:!1,drawOnChartArea:!1,drawBorder:!1},border:{display:!0,color:`#9FA2BD`}}}}));return(e,a)=>(n(),r(`div`,d,[i(`div`,f,[o(s(t),{type:p.value,data:m.value,options:h.value,"aria-label":`${e.widget.name||e.$t(`g.chart`)} - ${p.value} ${e.$t(`g.chartLowercase`)}`},null,8,[`type`,`data`,`options`,`aria-label`])])]))}});export{p as default};
//# sourceMappingURL=WidgetChart-Bl3dkM_H.js.map