import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{Y as t,i as n,n as r,r as i,rt as a}from"./vendor-primevue-7po8Zk9v.js";import{$ as o,A as s,Bt as c,D as l,E as u,F as d,Ft as f,L as p,O as m,P as h,ht as g,k as _}from"./vendor-vue-core-D3IvUUeM.js";import{W as v}from"./vendor-vueuse-ChSVzIZz.js";import{n as y}from"./vendor-i18n-CsAN_zFP.js";import{t as b}from"./Button-mG8zDgxj.js";import{wr as x}from"./dialogService-BC0EXJA5.js";import{r as S}from"./signInSchema-DbixSTrZ.js";import{t as C}from"./PasswordFields-D8F7TaOn.js";var w={class:`mb-2 text-base font-medium opacity-80`,for:`comfy-org-sign-up-email`},T={key:0,class:`text-red-500`},E=p({__name:`SignUpForm`,emits:[`submit`],setup(e,{emit:p}){let{t:E}=y(),D=x(),O=u(()=>D.loading),k=p,A=v(e=>{e.valid&&k(`submit`,e.values)},1500);return(e,u)=>(o(),m(f(n),{class:`flex flex-col gap-6`,resolver:f(r)(f(S)),onSubmit:f(A)},{default:g(e=>[d(f(i),{name:`email`,class:`flex flex-col gap-2`},{default:g(e=>[l(`label`,w,c(f(E)(`auth.signup.emailLabel`)),1),d(f(a),{"pt:root:id":`comfy-org-sign-up-email`,"pt:root:autocomplete":`email`,class:`h-10`,type:`text`,placeholder:f(E)(`auth.signup.emailPlaceholder`),invalid:e.invalid},null,8,[`placeholder`,`invalid`]),e.error?(o(),s(`small`,T,c(e.error.message),1)):_(``,!0)]),_:1}),d(C),O.value?(o(),m(f(t),{key:0,class:`mx-auto h-8 w-8`})):(o(),m(b,{key:1,type:`submit`,class:`mt-4 h-10 font-medium`,disabled:!e.valid},{default:g(()=>[h(c(f(E)(`auth.signup.signUpButton`)),1)]),_:2},1032,[`disabled`]))]),_:1},8,[`resolver`,`onSubmit`]))}});export{E as t};
//# sourceMappingURL=SignUpForm-B9cCgfYU.js.map