import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{j as t,s as n}from"./vendor-primevue-7po8Zk9v.js";import{$ as r,A as i,Bt as a,E as o,F as s,Ft as c,G as l,L as u,Lt as d,O as f,W as p,ct as m,ht as h,k as g,lt as _,y as v}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import{t as y}from"./src-ByuP5s1t.js";import{r as b}from"./widgetTypes-DWH_HSBH.js";import{o as x,r as S}from"./widgetPropFilter-AWF4Ovcm.js";import{t as C}from"./layout-CjPuhCDQ.js";var w=[`for`],T=u({__name:`WidgetTextarea`,props:p({widget:{},placeholder:{default:``}},{modelValue:{default:``},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let u=_(e,`modelValue`),p=b(),T=o(()=>x(e.widget.options,S)),E=o(()=>e.widget.label||e.widget.name),D=m(),O=o(()=>e.widget.options?.read_only??!1);return(e,o)=>(r(),f(c(t),{variant:`in`,unstyled:c(p),class:d(c(y)(`rounded-lg space-y-1 focus-within:ring focus-within:ring-component-node-widget-background-highlighted transition-all`,e.widget.borderStyle))},{default:h(()=>[s(c(n),l(T.value,{id:c(D),modelValue:u.value,"onUpdate:modelValue":o[0]||=e=>u.value=e,class:c(y)(c(C),`size-full text-xs resize-none`),placeholder:e.placeholder,readonly:O.value,disabled:O.value,fluid:``,"data-capture-wheel":`true`,onPointerdownCapture:o[1]||=v(()=>{},[`stop`]),onPointermoveCapture:o[2]||=v(()=>{},[`stop`]),onPointerupCapture:o[3]||=v(()=>{},[`stop`]),onContextmenuCapture:o[4]||=v(()=>{},[`stop`])}),null,16,[`id`,`modelValue`,`class`,`placeholder`,`readonly`,`disabled`]),c(p)?g(``,!0):(r(),i(`label`,{key:0,for:c(D)},a(E.value),9,w))]),_:1},8,[`unstyled`,`class`]))}});export{T as default};
//# sourceMappingURL=WidgetTextarea-CMzQ2i7R.js.map