import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{T as t,r as n}from"./vendor-primevue-7po8Zk9v.js";import{$ as r,A as i,Bt as a,D as o,E as s,Et as c,F as l,Ft as u,L as d,Lt as f,P as p,ht as m,k as h,x as g}from"./vendor-vue-core-D3IvUUeM.js";import{n as _}from"./vendor-i18n-CsAN_zFP.js";var v={class:`mb-2 flex items-center justify-between`},y={class:`text-base font-medium opacity-80`,for:`comfy-org-sign-up-password`},b={class:`flex flex-col gap-1`},x={key:0,class:`text-sm`},S={class:`mt-1 space-y-1`},C={class:`mb-2 text-base font-medium opacity-80`,for:`comfy-org-sign-up-confirm-password`},w={key:0,class:`text-red-500`},T=d({__name:`PasswordFields`,setup(e){let{t:d}=_(),T=c(``),E=s(()=>({length:T.value.length>=8&&T.value.length<=32,uppercase:/[A-Z]/.test(T.value),lowercase:/[a-z]/.test(T.value),number:/\d/.test(T.value),special:/[^A-Za-z0-9]/.test(T.value)}));return(e,s)=>(r(),i(g,null,[l(u(n),{name:`password`,class:`flex flex-col gap-2`},{default:m(e=>[o(`div`,v,[o(`label`,y,a(u(d)(`auth.signup.passwordLabel`)),1)]),l(u(t),{modelValue:T.value,"onUpdate:modelValue":s[0]||=e=>T.value=e,"input-id":`comfy-org-sign-up-password`,"pt:pc-input-text:root:autocomplete":`new-password`,name:`password`,feedback:!1,"toggle-mask":``,placeholder:u(d)(`auth.signup.passwordPlaceholder`),class:f([{"p-invalid":e.invalid},`h-10`]),fluid:``},null,8,[`modelValue`,`placeholder`,`class`]),o(`div`,b,[e.dirty||e.invalid?(r(),i(`small`,x,[p(a(u(d)(`validation.password.requirements`))+`: `,1),o(`ul`,S,[o(`li`,{class:f({"text-red-500":!E.value.length})},a(u(d)(`validation.password.minLength`)),3),o(`li`,{class:f({"text-red-500":!E.value.uppercase})},a(u(d)(`validation.password.uppercase`)),3),o(`li`,{class:f({"text-red-500":!E.value.lowercase})},a(u(d)(`validation.password.lowercase`)),3),o(`li`,{class:f({"text-red-500":!E.value.number})},a(u(d)(`validation.password.number`)),3),o(`li`,{class:f({"text-red-500":!E.value.special})},a(u(d)(`validation.password.special`)),3)])])):h(``,!0)])]),_:1}),l(u(n),{name:`confirmPassword`,class:`flex flex-col gap-2`},{default:m(e=>[o(`label`,C,a(u(d)(`auth.login.confirmPasswordLabel`)),1),l(u(t),{name:`confirmPassword`,"input-id":`comfy-org-sign-up-confirm-password`,"pt:pc-input-text:root:autocomplete":`new-password`,feedback:!1,"toggle-mask":``,placeholder:u(d)(`auth.login.confirmPasswordPlaceholder`),class:f([{"p-invalid":e.invalid},`h-10`]),fluid:``},null,8,[`placeholder`,`class`]),e.error?(r(),i(`small`,w,a(e.error.message),1)):h(``,!0)]),_:1})],64))}});export{T as t};
//# sourceMappingURL=PasswordFields-D8F7TaOn.js.map