import{r as e}from"./rolldown-runtime-DCMCV6zW.js";const t=[`style`,`class`,`dt`,`pt`,`ptOptions`,`unstyled`],n=[...t,`inputClass`,`inputStyle`],r=[...t,`panelClass`,`panelStyle`,`overlayClass`],i=[...t,`thumbnailsPosition`,`verticalThumbnailViewPortHeight`,`indicatorsPosition`,`maskClass`,`containerStyle`,`containerClass`,`galleriaClass`],a=[...t,`badgeClass`];function filterWidgetProps(e,t){if(!e)return{};let n={};for(let[r,i]of Object.entries(e))t.includes(r)||(n[r]=i);return n}export{t as a,r as i,i as n,filterWidgetProps as o,n as r,a as t};
//# sourceMappingURL=widgetPropFilter-AWF4Ovcm.js.map