import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,Bt as n,D as r,E as i,L as a,O as o,P as s,gt as c,ht as l,it as u}from"./vendor-vue-core-D3IvUUeM.js";import{t as d}from"./types-0oh-UGWL.js";import{c as f,r as p}from"./vendor-vueuse-ChSVzIZz.js";import{n as m}from"./vendor-i18n-CsAN_zFP.js";import{t as h}from"./Button-mG8zDgxj.js";import{V as g,_n as _}from"./dialogService-BC0EXJA5.js";var v=a({__name:`SubscribeToRun`,setup(e){let{t:a}=m(),v=f(p).greaterOrEqual(`md`),y=i(()=>v.value?a(`subscription.subscribeToRunFull`):a(`subscription.subscribeToRun`)),{showSubscriptionDialog:b}=_(),handleSubscribeToRun=()=>{d&&g()?.trackRunButton({subscribe_to_run:!0}),b()};return(e,i)=>{let a=u(`tooltip`);return c((t(),o(h,{class:`subscribe-to-run-button whitespace-nowrap`,variant:`primary`,size:`sm`,style:{background:`var(--color-subscription-button-gradient)`,color:`var(--color-white)`,borderColor:`transparent`},"data-testid":`subscribe-to-run-button`,onClick:handleSubscribeToRun},{default:l(()=>[i[0]||=r(`i`,{class:`pi pi-lock`},null,-1),s(` `+n(y.value),1)]),_:1})),[[a,{value:e.$t(`subscription.subscribeToRunFull`),showDelay:600},void 0,{bottom:!0}]])}}});export{v as t};
//# sourceMappingURL=SubscribeToRun-CEY5usAO.js.map