@font-face{font-family:ABC ROM Extended;src:local(ABC ROM Extended Black Italic),local(ABCRom BlackItalic),url(./ABCROMExtended-BlackItalic-NFqMndLW.woff2)format("woff2"),url(./ABCROMExtended-BlackItalic-B3Ak1JoQ.woff)format("woff");font-weight:900;font-style:italic;font-display:swap}.hero-title,.font-abcrom{font-synthesis:none;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-rendering:optimizeLegibility;font-family:ABC ROM Extended,sans-serif}.hero-title{text-transform:uppercase;text-shadow:0 4px 4px #00000040;font-size:32px;font-style:italic;font-weight:900;line-height:1.1}
