import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,Bt as r,D as i,E as a,L as o,k as s,tt as c,x as l}from"./vendor-vue-core-D3IvUUeM.js";var u={class:`flex w-[490px] flex-col border-t-1 border-border-default`},d={class:`flex h-full w-full flex-col gap-4 p-4`},f={key:0,class:`flex flex-col gap-3`},p=[`aria-label`],m={key:0,class:`text-xs p-4 rounded-md bg-secondary-background font-mono`},h=o({__name:`ImportFailedNodeContent`,props:{conflictedPackages:{}},setup(e){let o=a(()=>e.conflictedPackages.filter(e=>e.conflicts.some(e=>e.type===`import_failed`)).map(e=>{let t=e.conflicts.find(e=>e.type===`import_failed`);return t?{packageId:e.package_id,packageName:e.package_name,errorMessage:t.current_value||`Unknown import error`,traceback:t.required_value||``}:{packageId:e.package_id,packageName:e.package_name,errorMessage:`Unknown import error`,traceback:``}}));return(e,a)=>(t(),n(`div`,u,[i(`div`,d,[o.value.length>0?(t(),n(`div`,f,[(t(!0),n(l,null,c(o.value,e=>(t(),n(`div`,{key:e.packageId,class:`flex flex-col gap-2 max-h-60 overflow-x-hidden overflow-y-auto scrollbar-custom`,role:`region`,"aria-label":`Error traceback for ${e.packageId}`,tabindex:`0`},[e.traceback||e.errorMessage?(t(),n(`div`,m,r(e.traceback||e.errorMessage),1)):s(``,!0)],8,p))),128))])):s(``,!0)])]))}});export{h as default};
//# sourceMappingURL=ImportFailedNodeContent-BjM-2COI.js.map