import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,Bt as r,D as i}from"./vendor-vue-core-D3IvUUeM.js";import{t as a}from"./_plugin-vue_export-helper-CTPoQIH5.js";var o={},s={class:`flex h-12 w-full items-center justify-between pl-6`},c={class:`flex items-center gap-2`},l={class:`text-base font-bold`};function _sfc_render(e,a){return t(),n(`div`,s,[i(`div`,c,[a[0]||=i(`i`,{class:`icon-[lucide--triangle-alert] text-warning-background`},null,-1),i(`p`,l,r(e.$t(`manager.conflicts.title`)),1)])])}var u=a(o,[[`render`,_sfc_render]]);export{u as default};
//# sourceMappingURL=NodeConflictHeader-CtISOBi5.js.map