import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{n as t}from"./vendor-zod-D3H3ICYK.js";import{o as n}from"./i18n-DjEVEIh2.js";const r=t.object({apiKey:t.string().trim().startsWith(`comfyui-`,n(`validation.prefix`,{prefix:`comfyui-`})).length(72,n(`validation.length`,{length:72}))}),i=t.object({email:t.string().email(n(`validation.invalidEmail`)).min(1,n(`validation.required`)),password:t.string().min(1,n(`validation.required`))});var a=t.object({password:t.string().min(8,n(`validation.minLength`,{length:8})).max(32,n(`validation.maxLength`,{length:32})).regex(/[A-Z]/,n(`validation.password.uppercase`)).regex(/[a-z]/,n(`validation.password.lowercase`)).regex(/\d/,n(`validation.password.number`)).regex(/[^A-Za-z0-9]/,n(`validation.password.special`)),confirmPassword:t.string().min(1,n(`validation.required`))});const o=a.refine(e=>e.password===e.confirmPassword,{message:n(`validation.password.match`),path:[`confirmPassword`]}),s=a.extend({email:t.string().email(n(`validation.invalidEmail`)).min(1,n(`validation.required`))}).refine(e=>e.password===e.confirmPassword,{message:n(`validation.password.match`),path:[`confirmPassword`]});export{o as i,i as n,s as r,r as t};
//# sourceMappingURL=signInSchema-DbixSTrZ.js.map