import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,Bt as r,D as i,Ft as a,L as o}from"./vendor-vue-core-D3IvUUeM.js";import{t as s}from"./types-0oh-UGWL.js";var c={class:`flex w-full items-center justify-between p-4`},l={class:`flex items-center gap-2`},u={class:`m-0 text-sm`},d=o({__name:`MissingNodesHeader`,setup(e){return(e,o)=>(t(),n(`div`,c,[i(`div`,l,[o[0]||=i(`i`,{class:`icon-[lucide--triangle-alert] text-warning-background`},null,-1),i(`p`,u,r(a(s)?e.$t(`missingNodes.cloud.title`):e.$t(`missingNodes.oss.title`)),1)])]))}});export{d as default};
//# sourceMappingURL=MissingNodesHeader-BaeZ03n0.js.map