import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{E as t}from"./vendor-vue-core-D3IvUUeM.js";import{n,t as r}from"./envUtil-DPL4J8Ws.js";import{n as i}from"./i18n-DjEVEIh2.js";function useExternalLink(){let e=t(()=>String(i.global.locale.value)),a=t(()=>e.value===`zh`||e.value===`zh-TW`),o=t(()=>n()?r().getPlatform()===`darwin`?`macos`:`windows`:null),buildDocsUrl=(e,t={})=>{let{includeLocale:n=!1,platform:r=!1}=t,i=`https://docs.comfy.org`;n&&a.value&&(i+=`/zh-CN`);let s=e.startsWith(`/`)?e:`/${e}`;return i+=s,r&&o.value&&(i=i.endsWith(`/`)?i:`${i}/`,i+=o.value),i};return{buildDocsUrl,staticUrls:{discord:`https://www.comfy.org/discord`,github:`https://github.com/comfyanonymous/ComfyUI`,githubIssues:`https://github.com/comfyanonymous/ComfyUI/issues`,githubFrontend:`https://github.com/Comfy-Org/ComfyUI_frontend`,githubElectron:`https://github.com/Comfy-Org/electron`,forum:`https://forum.comfy.org/`,comfyOrg:`https://www.comfy.org/`},docsPaths:{partnerNodesPricing:`/tutorials/partner-nodes/pricing`}}}export{useExternalLink as t};
//# sourceMappingURL=useExternalLink-BZoBzmNd.js.map