/*! tailwindcss v4.1.12 | MIT License | https://tailwindcss.com */
[data-v-f7040d8a] .p-terminal .xterm{overflow:hidden}[data-v-f7040d8a] .p-terminal .xterm-screen{background-color:var(--color-neutral-900,#171717);overflow:hidden}@supports (color:lab(0% 0 0)){[data-v-f7040d8a] .p-terminal .xterm-screen{background-color:var(--color-neutral-900,lab(7.78201% -.0000149012 0))}}[data-v-c03d3536] .p-terminal .xterm{overflow-x:auto}[data-v-c03d3536] .p-terminal .xterm-screen{overflow-y:hidden}[data-v-49782f06] .p-terminal .xterm{overflow-x:auto}[data-v-49782f06] .p-terminal .xterm-screen{overflow-y:hidden}
