import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,Et as r,F as i,Ft as a,G as o,L as s,Lt as c,O as l,ht as u,tt as d,x as f}from"./vendor-vue-core-D3IvUUeM.js";import{L as p}from"./vendor-vueuse-ChSVzIZz.js";import{c as m,j as h,l as g,o as _,s as v}from"./vendor-reka-ui-Bm3o_ZTf.js";import{t as y}from"./src-ByuP5s1t.js";var b=s({__name:`Slider`,props:{defaultValue:{},modelValue:{},disabled:{type:Boolean},orientation:{},dir:{},inverted:{type:Boolean},min:{},max:{},step:{},minStepsBetweenThumbs:{},thumbAlignment:{},asChild:{type:Boolean},as:{},name:{},required:{type:Boolean},class:{}},emits:[`update:modelValue`,`valueCommit`],setup(e,{emit:s}){let b=e,x=r(!1),setPressed=e=>{x.value=e},S=s,C=h(p(b,`class`),S);return(e,r)=>(t(),l(a(g),o({"data-slot":`slider`,class:a(y)(`relative flex w-full touch-none items-center select-none data-[disabled]:opacity-50`,`data-[orientation=vertical]:h-full data-[orientation=vertical]:min-h-44 data-[orientation=vertical]:w-auto data-[orientation=vertical]:flex-col`,b.class)},a(C),{onSlideStart:r[0]||=()=>setPressed(!0),onSlideMove:r[1]||=()=>setPressed(!0),onSlideEnd:r[2]||=()=>setPressed(!1)}),{default:u(({modelValue:e})=>[i(a(_),{"data-slot":`slider-track`,class:c(a(y)(`bg-node-stroke relative grow overflow-hidden rounded-full`,`cursor-pointer overflow-visible`,`before:absolute before:-inset-2 before:block before:bg-transparent`,`data-[orientation=horizontal]:h-0.5 data-[orientation=horizontal]:w-full`,`data-[orientation=vertical]:h-full data-[orientation=vertical]:w-0.5`))},{default:u(()=>[i(a(m),{"data-slot":`slider-range`,class:`absolute bg-node-component-surface-highlight data-[orientation=horizontal]:h-full data-[orientation=vertical]:w-full`})]),_:1},8,[`class`]),(t(!0),n(f,null,d(e,(e,n)=>(t(),l(a(v),{key:n,"data-slot":`slider-thumb`,class:c(a(y)(`bg-node-component-surface-highlight ring-node-component-surface-selected block size-3.5 shrink-0 rounded-full shadow-sm transition-[color,box-shadow]`,`cursor-grab`,`before:absolute before:-inset-1 before:block before:bg-transparent before:rounded-full`,`hover:ring-2 focus-visible:ring-2 focus-visible:outline-hidden disabled:pointer-events-none disabled:opacity-50`,{"cursor-grabbing":x.value}))},null,8,[`class`]))),128))]),_:1},16,[`class`]))}});export{b as t};
//# sourceMappingURL=Slider-Bn8frMD_.js.map