import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,Bt as r,D as i,Ft as a,L as o,Lt as s,P as c,k as l,nt as u,x as d,y as f}from"./vendor-vue-core-D3IvUUeM.js";import{t as p}from"./src-ByuP5s1t.js";import{r as m}from"./widgetTypes-DWH_HSBH.js";var h={class:`grid grid-cols-subgrid min-w-0 justify-between gap-1 text-node-component-slot-text`},g={key:0,class:`truncate content-center-safe`},_={class:`relative min-w-0 flex-1`},v=o({__name:`WidgetLayoutField`,props:{widget:{}},setup(e){let o=m();return(e,m)=>(t(),n(`div`,h,[a(o)?l(``,!0):(t(),n(`div`,g,[e.widget.name?(t(),n(d,{key:0},[c(r(e.widget.label||e.widget.name),1)],64)):l(``,!0)])),i(`div`,_,[i(`div`,{class:s(a(p)(`cursor-default min-w-0 rounded-lg focus-within:ring focus-within:ring-component-node-widget-background-highlighted transition-all`,e.widget.borderStyle)),onPointerdown:m[0]||=f(()=>{},[`stop`]),onPointermove:m[1]||=f(()=>{},[`stop`]),onPointerup:m[2]||=f(()=>{},[`stop`])},[u(e.$slots,`default`)],34)])]))}});export{v as t};
//# sourceMappingURL=WidgetLayoutField-Dp_aV9P0.js.map