.settings-tab-panels{padding-top:0!important}.settings-container[data-v-c3e623ff]{width:60vw;max-width:64rem;height:70vh;display:flex;overflow:hidden}.settings-content[data-v-c3e623ff]{overflow-x:auto}@media (max-width:768px){.settings-container[data-v-c3e623ff]{flex-direction:column;width:80vw;height:auto}.settings-sidebar[data-v-c3e623ff]{width:100%}.settings-content[data-v-c3e623ff]{height:350px}}.settings-sidebar[data-v-c3e623ff] .p-listbox-option-group:first-child{display:none}
