import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{rt as t}from"./vendor-primevue-7po8Zk9v.js";import{$ as n,E as r,F as i,Ft as a,G as o,L as s,O as c,W as l,ht as u,lt as d}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import{t as f}from"./src-ByuP5s1t.js";import{o as p,r as m}from"./widgetPropFilter-AWF4Ovcm.js";import{t as h}from"./layout-CjPuhCDQ.js";import{t as g}from"./WidgetLayoutField-Dp_aV9P0.js";var _=s({__name:`WidgetInputText`,props:l({widget:{}},{modelValue:{default:``},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let s=e,l=d(e,`modelValue`),_=r(()=>p(s.widget.options,m));return(e,r)=>(n(),c(g,{widget:e.widget},{default:u(()=>[i(a(t),o({modelValue:l.value,"onUpdate:modelValue":r[0]||=e=>l.value=e},_.value,{class:a(f)(a(h),`w-full text-xs py-2 px-4`),"aria-label":e.widget.name,size:`small`,pt:{root:`truncate min-w-[4ch]`}}),null,16,[`modelValue`,`class`,`aria-label`])]),_:1},8,[`widget`]))}});export{_ as default};
//# sourceMappingURL=WidgetInputText-BTrqSaqd.js.map