import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{i as t,n}from"./vendor-primevue-7po8Zk9v.js";import"./vendor-firebase-CdLSXhbt.js";import{$ as r,Bt as i,Et as a,F as o,Ft as s,L as c,O as l,P as u,ht as d}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import"./types-0oh-UGWL.js";import"./remoteConfig-CNDr9CtS.js";import"./api-3C7_IVZO.js";import"./colorUtil-C83P1Arv.js";import"./i18n-DjEVEIh2.js";import"./useErrorHandling-CBX3YQ5l.js";import"./vendor-reka-ui-Bm3o_ZTf.js";import{t as f}from"./Button-mG8zDgxj.js";import{wn as p}from"./dialogService-BC0EXJA5.js";import"./systemStatsStore-gvlzOl4W.js";import"./dialogStore-BbHfkjRE.js";import"./useCopyToClipboard-CUuoo5Dm.js";import"./vendor-tiptap-DsZVujQD.js";import"./vendor-markdown-yjaB1jgA.js";import"./markdownRendererUtil-D5cHPoK2.js";import{i as m}from"./signInSchema-DbixSTrZ.js";import{t as h}from"./PasswordFields-D8F7TaOn.js";var g=c({__name:`UpdatePasswordContent`,props:{onSuccess:{type:Function}},setup(e){let c=p(),g=a(!1),onSubmit=async t=>{if(t.valid){g.value=!0;try{await c.updatePassword(t.values.password),e.onSuccess()}finally{g.value=!1}}};return(e,a)=>(r(),l(s(t),{class:`flex w-96 flex-col gap-6`,resolver:s(n)(s(m)),onSubmit},{default:d(()=>[o(h),o(f,{type:`submit`,class:`mt-4 h-10 font-medium`,loading:g.value},{default:d(()=>[u(i(e.$t(`userSettings.updatePassword`)),1)]),_:1},8,[`loading`])]),_:1},8,[`resolver`]))}});export{g as default};
//# sourceMappingURL=UpdatePasswordContent-Dk2gMqQL.js.map