import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-7po8Zk9v.js";import{$ as t,A as n,Bt as r,D as i,F as a,Ft as o,L as s,P as c,ht as l,rt as u}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import{n as d}from"./vendor-i18n-CsAN_zFP.js";import"./i18n-DjEVEIh2.js";import"./vendor-reka-ui-Bm3o_ZTf.js";import{t as f}from"./Button-mG8zDgxj.js";import{t as p}from"./useExternalLink-BZoBzmNd.js";var m={class:`flex h-110 max-w-96 flex-col gap-4 p-2`},h={class:`mb-2 text-2xl font-medium`},g={class:`mb-4 text-base`},_={class:`flex items-center justify-between`},v={class:`flex gap-2`},y=s({__name:`ApiNodesSignInContent`,props:{apiNodeNames:{},onLogin:{type:Function},onCancel:{type:Function}},setup(e){let{t:s}=d(),{buildDocsUrl:y}=p(),handleLearnMoreClick=()=>{window.open(y(`/tutorials/api-nodes/faq`,{includeLocale:!0}),`_blank`)};return(e,d)=>{let p=u(`ApiNodesList`);return t(),n(`div`,m,[i(`div`,h,r(o(s)(`apiNodesSignInDialog.title`)),1),i(`div`,g,r(o(s)(`apiNodesSignInDialog.message`)),1),a(p,{"node-names":e.apiNodeNames},null,8,[`node-names`]),i(`div`,_,[a(f,{variant:`textonly`,onClick:handleLearnMoreClick},{default:l(()=>[c(r(o(s)(`g.learnMore`)),1)]),_:1}),i(`div`,v,[a(f,{variant:`secondary`,onClick:d[0]||=t=>e.onCancel?.()},{default:l(()=>[c(r(o(s)(`g.cancel`)),1)]),_:1}),a(f,{onClick:d[1]||=t=>e.onLogin?.()},{default:l(()=>[c(r(o(s)(`g.login`)),1)]),_:1})])])])}}});export{y as default};
//# sourceMappingURL=ApiNodesSignInContent-DxchJUmj.js.map