import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,D as r,Et as i,Ft as a,K as o,L as s,Lt as c,X as l,_ as u,gt as d,nt as f}from"./vendor-vue-core-D3IvUUeM.js";import{n as p,r as m,t as h}from"./envUtil-DPL4J8Ws.js";var g={class:`flex w-full grow items-center justify-center overflow-auto`},_=s({__name:`BaseViewTemplate`,props:{dark:{type:Boolean,default:!1}},setup(e){let s={color:`rgba(0, 0, 0, 0)`,symbolColor:`#d4d4d4`},_={color:`rgba(0, 0, 0, 0)`,symbolColor:`#171717`},v=i(null);return l(async()=>{p()&&(await o(),h().changeTheme({...e.dark?s:_,height:v.value?.getBoundingClientRect().height??0}))}),(e,i)=>(t(),n(`div`,{class:c([`flex h-svh w-screen flex-col font-sans`,[e.dark?`dark-theme bg-neutral-900 text-neutral-300`:`bg-neutral-300 text-neutral-900`]])},[d(r(`div`,{ref_key:`topMenuRef`,ref:v,class:`app-drag h-(--comfy-topbar-height) w-full`},null,512),[[u,a(m)()]]),r(`div`,g,[f(e.$slots,`default`)])],2))}});export{_ as t};
//# sourceMappingURL=BaseViewTemplate-BY8GIa0B.js.map