import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-7po8Zk9v.js";import"./vendor-firebase-CdLSXhbt.js";import"./vendor-other-CrvBxfcV.js";import"./types-0oh-UGWL.js";import"./remoteConfig-CNDr9CtS.js";import"./api-3C7_IVZO.js";import"./colorUtil-C83P1Arv.js";import{o as t}from"./i18n-DjEVEIh2.js";import"./useErrorHandling-CBX3YQ5l.js";import"./vendor-reka-ui-Bm3o_ZTf.js";import"./Button-mG8zDgxj.js";import{tn as n}from"./dialogService-BC0EXJA5.js";import"./systemStatsStore-gvlzOl4W.js";import"./dialogStore-BbHfkjRE.js";import"./useCopyToClipboard-CUuoo5Dm.js";import"./vendor-tiptap-DsZVujQD.js";import"./vendor-markdown-yjaB1jgA.js";import"./markdownRendererUtil-D5cHPoK2.js";import{r,t as i}from"./config-C9O0f1Fo.js";var a=`https://support.comfy.org/hc/en-us/requests/new`,o=`43066738713236`,s=r(),c=`${a}?${new URLSearchParams({ticket_form_id:o,[i.DISTRIBUTION]:s}).toString()}`,l=[{icon:`icon-[lucide--message-circle-question-mark]`,label:t(`actionbar.feedback`),tooltip:t(`actionbar.feedbackTooltip`),onClick:()=>{window.open(c,`_blank`,`noopener,noreferrer`)}}];n().registerExtension({name:`Comfy.Cloud.FeedbackButton`,actionBarButtons:l});
//# sourceMappingURL=cloudFeedbackTopbarButton-BIWfkMfM.js.map