const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./SubscriptionRequiredDialogContent-DUfT6N_1.js","./_plugin-vue_export-helper-CTPoQIH5.js","./rolldown-runtime-DCMCV6zW.js","./vendor-primevue-7po8Zk9v.js","./vendor-vue-core-D3IvUUeM.js","./dialogService-BC0EXJA5.js","./vendor-other-CrvBxfcV.js","./vendor-firebase-CdLSXhbt.js","./vendor-three-Qz0FU1fN.js","./vendor-tiptap-DsZVujQD.js","./vendor-reka-ui-Bm3o_ZTf.js","./vendor-i18n-CsAN_zFP.js","./vendor-vueuse-ChSVzIZz.js","./vendor-axios-BKU8NR6A.js","./vendor-zod-D3H3ICYK.js","./systemStatsStore-gvlzOl4W.js","./api-3C7_IVZO.js","./vendor-yjs-bg4j8JjP.js","./i18n-DjEVEIh2.js","./widget-B3lMdpiR.js","./types-0oh-UGWL.js","./envUtil-DPL4J8Ws.js","./colorUtil-C83P1Arv.js","./src-ByuP5s1t.js","./Button-mG8zDgxj.js","./SelectValue-Dja3qCIp.js","./useCopyToClipboard-CUuoo5Dm.js","./useErrorHandling-CBX3YQ5l.js","./remoteConfig-CNDr9CtS.js","./dialogStore-BbHfkjRE.js","./widgetTypes-DWH_HSBH.js","./markdownRendererUtil-D5cHPoK2.js","./vendor-markdown-yjaB1jgA.js","./CloudBadge-X_7NrxNx.js","./TopbarBadge-7alRBk84.js","./SubscribeButton-BzxsFjxi.js","./subscriptionCheckoutUtil-B_HowdP4.js","./vendor-other-CaaUC6Qe.css","./dialogService-Dpt-OVzG.css","./SubscriptionRequiredDialogContent-CiHdewCw.css"])))=>i.map(i=>d[i]);
import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{ut as t}from"./vendor-primevue-7po8Zk9v.js";import{I as n}from"./vendor-vue-core-D3IvUUeM.js";import{t as r}from"./dialogService-BC0EXJA5.js";import{t as i}from"./dialogStore-BbHfkjRE.js";var a=`subscription-required`;const useSubscriptionDialog=()=>{let e=r(),o=i();function hide(){o.closeDialog({key:a})}function show(){e.showLayoutDialog({key:a,component:n(()=>t(()=>import(`./SubscriptionRequiredDialogContent-DUfT6N_1.js`),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39]),import.meta.url)),props:{onClose:hide},dialogComponentProps:{style:`width: min(1328px, 95vw); max-height: 90vh;`,pt:{root:{class:`rounded-2xl bg-transparent`},content:{class:`!p-0 rounded-2xl border border-border-default bg-base-background/60 backdrop-blur-md shadow-[0_25px_80px_rgba(5,6,12,0.45)]`}}}})}return{show,hide}};export{useSubscriptionDialog as t};
//# sourceMappingURL=useSubscriptionDialog-BDF7ouOb.js.map