import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,Ft as r,L as i,Lt as a,O as o,ht as s,k as c,nt as l}from"./vendor-vue-core-D3IvUUeM.js";import{O as u}from"./vendor-other-CrvBxfcV.js";import{A as d}from"./vendor-reka-ui-Bm3o_ZTf.js";import{t as f}from"./src-ByuP5s1t.js";const p=u({base:`relative inline-flex items-center justify-center gap-2 cursor-pointer whitespace-nowrap appearance-none border-none rounded-md text-sm font-medium font-inter transition-colors focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none [&_svg]:size-4 [&_svg]:shrink-0`,variants:{variant:{secondary:`bg-secondary-background text-secondary-foreground hover:bg-secondary-background-hover`,primary:`bg-primary-background text-base-foreground hover:bg-primary-background-hover`,inverted:`bg-base-foreground text-base-background hover:bg-base-foreground/80`,destructive:`bg-destructive-background text-base-foreground hover:bg-destructive-background-hover`,textonly:`text-base-foreground bg-transparent hover:bg-secondary-background-hover`,"muted-textonly":`text-muted-foreground bg-transparent hover:bg-secondary-background-hover`,"destructive-textonly":`text-destructive-background bg-transparent hover:bg-destructive-background/10`,"overlay-white":`bg-white text-gray-600 hover:bg-white/90`},size:{sm:`h-6 rounded-sm px-2 py-1 text-xs`,md:`h-8 rounded-lg p-2 text-xs`,lg:`h-10 rounded-lg px-4 py-2 text-sm`,icon:`size-8`,"icon-sm":`size-5 p-0`,unset:``}},defaultVariants:{variant:`secondary`,size:`md`}});var m={key:0,class:`pi pi-spin pi-spinner`},h=i({__name:`Button`,props:{variant:{},size:{},class:{default:``},loading:{type:Boolean,default:!1},disabled:{type:Boolean,default:!1},asChild:{type:Boolean},as:{default:`button`}},setup(e){return(i,u)=>(t(),o(r(d),{as:i.as,"as-child":i.asChild,disabled:i.disabled||i.loading,class:a(r(f)(r(p)({variant:i.variant,size:i.size}),e.class))},{default:s(()=>[i.loading?(t(),n(`i`,m)):c(``,!0),i.loading?c(``,!0):l(i.$slots,`default`,{key:1})]),_:3},8,[`as`,`as-child`,`disabled`,`class`]))}});export{p as n,h as t};
//# sourceMappingURL=Button-mG8zDgxj.js.map