import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,E as n,L as r,O as i}from"./vendor-vue-core-D3IvUUeM.js";import{o as a}from"./i18n-DjEVEIh2.js";import{t as o}from"./TopbarBadge-7alRBk84.js";var s=r({__name:`CloudBadge`,props:{displayMode:{default:`full`},reverseOrder:{type:Boolean,default:!1},noPadding:{type:Boolean,default:!1},backgroundColor:{default:`var(--comfy-menu-bg)`}},setup(e){let r=n(()=>({label:a(`g.beta`),text:`Comfy Cloud`}));return(e,n)=>(t(),i(o,{badge:r.value,"display-mode":e.displayMode,"reverse-order":e.reverseOrder,"no-padding":e.noPadding,"background-color":e.backgroundColor},null,8,[`badge`,`display-mode`,`reverse-order`,`no-padding`,`background-color`]))}});export{s as t};
//# sourceMappingURL=CloudBadge-X_7NrxNx.js.map