import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{H as t}from"./vendor-primevue-7po8Zk9v.js";import{$ as n,E as r,Et as i,Ft as a,L as o,O as s}from"./vendor-vue-core-D3IvUUeM.js";var c=o({__name:`UserAvatar`,props:{photoUrl:{},ariaLabel:{}},setup(e){let o=i(!1),handleImageError=()=>{o.value=!0},c=r(()=>e.photoUrl&&!o.value);return(e,r)=>(n(),s(a(t),{class:`bg-interface-panel-selected-surface`,image:e.photoUrl??void 0,icon:c.value?void 0:`icon-[lucide--user]`,"pt:icon:class":{"size-4":!c.value},shape:`circle`,"aria-label":e.ariaLabel??e.$t(`auth.login.userAvatar`),onError:handleImageError},null,8,[`image`,`icon`,`pt:icon:class`,`aria-label`]))}});export{c as t};
//# sourceMappingURL=UserAvatar-RYLK1cyw.js.map