import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{E as t}from"./vendor-vue-core-D3IvUUeM.js";import{n}from"./vendor-i18n-CsAN_zFP.js";import{gt as r,wr as i}from"./dialogService-BC0EXJA5.js";function useSubscriptionCredits(){let e=i(),{locale:a}=n(),formatBalance=e=>r({cents:e??0,locale:a.value,numberOptions:{minimumFractionDigits:0,maximumFractionDigits:0}});return{totalCredits:t(()=>formatBalance(e.balance?.amount_micros)),monthlyBonusCredits:t(()=>formatBalance(e.balance?.cloud_credit_balance_micros)),prepaidCredits:t(()=>formatBalance(e.balance?.prepaid_balance_micros)),isLoadingBalance:t(()=>e.isFetchingBalance)}}export{useSubscriptionCredits as t};
//# sourceMappingURL=useSubscriptionCredits-6qVw9m02.js.map