import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,Bt as r,E as i,L as a,zt as o}from"./vendor-vue-core-D3IvUUeM.js";var s=a({__name:`WorkspaceProfilePic`,props:{workspaceName:{}},setup(e){let a=i(()=>e.workspaceName?.charAt(0)?.toUpperCase()??`?`),s=i(()=>{let e=a.value.charCodeAt(0);function mulberry32(e){return function(){let t=e+=1831565813;return t=Math.imul(t^t>>>15,t|1),t^=t+Math.imul(t^t>>>7,t|61),((t^t>>>14)>>>0)/4294967296}}let t=mulberry32(e),n=Math.floor(t()*360),r=(n+40+Math.floor(t()*80))%360,i=65+Math.floor(t()*20),o=55+Math.floor(t()*15);return`linear-gradient(135deg, hsl(${n}, ${i}%, ${o}%), hsl(${r}, ${i}%, ${o}%))`});return(e,i)=>(t(),n(`div`,{class:`flex size-8 items-center justify-center rounded-md text-base font-semibold text-white`,style:o({background:s.value,textShadow:`0 1px 2px rgba(0, 0, 0, 0.2)`})},r(a.value),5))}});export{s as t};
//# sourceMappingURL=WorkspaceProfilePic-D8zQxRDW.js.map