import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{c as t}from"./vendor-primevue-7po8Zk9v.js";import{$ as n,A as r,Bt as i,D as a,E as o,Ft as s,L as c,O as l,k as u}from"./vendor-vue-core-D3IvUUeM.js";import{t as d}from"./types-0oh-UGWL.js";import{r as f}from"./remoteConfig-CNDr9CtS.js";import{t as p}from"./_plugin-vue_export-helper-CTPoQIH5.js";var m=!1;const h=o(()=>d?(f.value.firebase_config?.projectId)?.includes(`-dev`)??m:m);var g={class:`px-4`},_=p(c({__name:`SettingDialogHeader`,setup(e){return(e,o)=>(n(),r(`div`,null,[a(`h2`,g,[o[0]||=a(`i`,{class:`pi pi-cog`},null,-1),a(`span`,null,i(e.$t(`g.settings`)),1),s(h)?(n(),l(s(t),{key:0,value:`staging`,severity:`warn`,class:`ml-2 text-xs`})):u(``,!0)])]))}}),[[`__scopeId`,`data-v-dcb7c822`]]);export{_ as t};
//# sourceMappingURL=SettingDialogHeader-CFuL6X4_.js.map