import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,Bt as r,E as i,F as a,G as o,L as s,Lt as c,P as l,ht as u,k as d}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import"./vendor-reka-ui-Bm3o_ZTf.js";import{t as f}from"./Button-mG8zDgxj.js";import{o as p,t as m}from"./widgetPropFilter-AWF4Ovcm.js";var h={class:`flex flex-col gap-1`},g=s({__name:`WidgetButton`,props:{widget:{}},setup(e){let s=e,g=[...m,`iconClass`],_=i(()=>p(s.widget.options,g)),handleClick=()=>{s.widget.callback&&s.widget.callback()};return(e,i)=>(t(),n(`div`,h,[a(f,o({class:`text-base-foreground w-full border-0 bg-component-node-widget-background p-2`,"aria-label":e.widget.label,size:`sm`,variant:`textonly`},_.value,{onClick:handleClick}),{default:u(()=>[l(r(e.widget.label??e.widget.name)+` `,1),e.widget.options?.iconClass?(t(),n(`i`,{key:0,class:c(e.widget.options.iconClass)},null,2)):d(``,!0)]),_:1},16,[`aria-label`])]))}});export{g as default};
//# sourceMappingURL=WidgetButton-T4Mk7PiJ.js.map