import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-7po8Zk9v.js";import"./vendor-firebase-CdLSXhbt.js";import{$ as t,E as n,Ft as r,L as i,O as a,at as o}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import"./types-0oh-UGWL.js";import"./remoteConfig-CNDr9CtS.js";import"./api-3C7_IVZO.js";import"./colorUtil-C83P1Arv.js";import"./i18n-DjEVEIh2.js";import"./useErrorHandling-CBX3YQ5l.js";import"./vendor-reka-ui-Bm3o_ZTf.js";import"./Button-mG8zDgxj.js";import{_n as s}from"./dialogService-BC0EXJA5.js";import"./systemStatsStore-gvlzOl4W.js";import"./dialogStore-BbHfkjRE.js";import"./useCopyToClipboard-CUuoo5Dm.js";import"./vendor-tiptap-DsZVujQD.js";import"./vendor-markdown-yjaB1jgA.js";import"./markdownRendererUtil-D5cHPoK2.js";import{t as c}from"./ComfyQueueButton-Cdk-jy75.js";import{t as l}from"./SubscribeToRun-CEY5usAO.js";var u=i({__name:`CloudRunButtonWrapper`,setup(e){let{isActiveSubscription:i}=s(),u=n(()=>i.value?c:l);return(e,n)=>(t(),a(o(u.value),{key:r(i)?`queue`:`subscribe`}))}});export{u as default};
//# sourceMappingURL=CloudRunButtonWrapper-BjmFpZ18.js.map