import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-7po8Zk9v.js";import{$ as t,A as n,Bt as r,D as i,F as a,L as o,O as s,P as c,ht as l,k as u}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import"./i18n-DjEVEIh2.js";import"./vendor-reka-ui-Bm3o_ZTf.js";import{t as d}from"./Button-mG8zDgxj.js";import{t as f}from"./dialogStore-BbHfkjRE.js";import{t as p}from"./useExternalLink-BZoBzmNd.js";var m={class:`flex w-full items-center justify-between px-3 py-4`},h={class:`flex w-full items-center justify-between gap-2 pr-1`},g=o({__name:`NodeConflictFooter`,props:{buttonText:{default:void 0},onButtonClick:{type:Function,default:void 0}},setup(e){let o=e,{buildDocsUrl:g}=p(),_=f(),handleConflictInfoClick=()=>{window.open(g(`/troubleshooting/custom-node-issues`,{includeLocale:!0}),`_blank`)},handleButtonClick=()=>{_.closeDialog({key:`global-node-conflict`}),o.onButtonClick&&o.onButtonClick()};return(e,f)=>(t(),n(`div`,m,[i(`div`,h,[a(d,{variant:`muted-textonly`,size:`sm`,class:`text-sm`,onClick:handleConflictInfoClick},{default:l(()=>[f[0]||=i(`i`,{class:`pi pi-info-circle`},null,-1),c(` `+r(e.$t(`manager.conflicts.conflictInfoTitle`)),1)]),_:1}),o.buttonText?(t(),s(d,{key:0,variant:`secondary`,size:`sm`,onClick:handleButtonClick},{default:l(()=>[c(r(o.buttonText),1)]),_:1})):u(``,!0)])]))}});export{g as default};
//# sourceMappingURL=NodeConflictFooter-DujIPzvp.js.map