import"./vendor-primevue-7po8Zk9v.js";import"./vendor-other-CrvBxfcV.js";import"./types-0oh-UGWL.js";import"./api-3C7_IVZO.js";import"./colorUtil-C83P1Arv.js";import"./i18n-DjEVEIh2.js";import{n as e,r as t,t as n}from"./auth-CwHXDOkG.js";export{n as getSurveyCompletedStatus};