// Shim for extensions/core/load3d/constants.ts
console.warn('[ComfyUI Notice] "extensions/core/load3d/constants.js" is an internal module, not part of the public API. Future updates may break this import.');
export const SUPPORTED_EXTENSIONS = window.comfyAPI.constants.SUPPORTED_EXTENSIONS;
