import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,Bt as r,D as i,E as a,L as o,g as s,gt as c,lt as l}from"./vendor-vue-core-D3IvUUeM.js";var u={class:`grid grid-cols-[auto_1fr] gap-x-2 gap-y-1`},d={class:`content-center text-xs text-node-component-slot-text`},f={class:`content-center text-xs text-node-component-slot-text`},p={class:`content-center text-xs text-node-component-slot-text`},m={class:`content-center text-xs text-node-component-slot-text`},h=o({__name:`WidgetBoundingBox`,props:{modelValue:{default:()=>({x:0,y:0,width:512,height:512})},modelModifiers:{}},emits:[`update:modelValue`],setup(e){let o=l(e,`modelValue`),h=a({get:()=>o.value.x,set:e=>{o.value={...o.value,x:e}}}),g=a({get:()=>o.value.y,set:e=>{o.value={...o.value,y:e}}}),_=a({get:()=>o.value.width,set:e=>{o.value={...o.value,width:e}}}),v=a({get:()=>o.value.height,set:e=>{o.value={...o.value,height:e}}});return(e,a)=>(t(),n(`div`,u,[i(`label`,d,r(e.$t(`boundingBox.x`)),1),c(i(`input`,{"onUpdate:modelValue":a[0]||=e=>h.value=e,type:`number`,min:0,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[s,h.value,void 0,{number:!0}]]),i(`label`,f,r(e.$t(`boundingBox.y`)),1),c(i(`input`,{"onUpdate:modelValue":a[1]||=e=>g.value=e,type:`number`,min:0,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[s,g.value,void 0,{number:!0}]]),i(`label`,p,r(e.$t(`boundingBox.width`)),1),c(i(`input`,{"onUpdate:modelValue":a[2]||=e=>_.value=e,type:`number`,min:1,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[s,_.value,void 0,{number:!0}]]),i(`label`,m,r(e.$t(`boundingBox.height`)),1),c(i(`input`,{"onUpdate:modelValue":a[3]||=e=>v.value=e,type:`number`,min:1,step:`1`,class:`h-7 rounded-lg border-none bg-component-node-widget-background px-2 text-xs text-component-node-foreground focus:outline-0`},null,512),[[s,v.value,void 0,{number:!0}]])]))}});export{h as t};
//# sourceMappingURL=WidgetBoundingBox-DSJC-Vib.js.map