import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-7po8Zk9v.js";import"./vendor-firebase-CdLSXhbt.js";import{$ as t,A as n,Bt as r,D as i,F as a,Ft as o,L as s,P as c,ht as l,nt as u,t as d,x as f}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import"./types-0oh-UGWL.js";import"./remoteConfig-CNDr9CtS.js";import"./api-3C7_IVZO.js";import"./colorUtil-C83P1Arv.js";import{n as p}from"./vendor-i18n-CsAN_zFP.js";import{o as m}from"./i18n-DjEVEIh2.js";import"./useErrorHandling-CBX3YQ5l.js";import"./vendor-reka-ui-Bm3o_ZTf.js";import{t as h}from"./Button-mG8zDgxj.js";import"./dialogService-BC0EXJA5.js";import"./systemStatsStore-gvlzOl4W.js";import{t as g}from"./_plugin-vue_export-helper-CTPoQIH5.js";import"./dialogStore-BbHfkjRE.js";import"./useCopyToClipboard-CUuoo5Dm.js";import"./vendor-tiptap-DsZVujQD.js";import"./vendor-markdown-yjaB1jgA.js";import"./markdownRendererUtil-D5cHPoK2.js";import{t as _}from"./GlobalToast-4SWy7DS6.js";import{t as v}from"./BaseViewTemplate-BY8GIa0B.js";var y=``+new URL(`thumbnail-imMA3y7Z.png`,import.meta.url).href,b=``+new URL(`video-BvOHf4P9.mp4`,import.meta.url).href,x=``+new URL(`images/comfy-cloud-logo.svg`,import.meta.url).href,S={},C={class:`mx-auto flex h-[7%] max-h-[70px] w-5/6 items-end`},w=[`alt`];function _sfc_render(e,r){return t(),n(`div`,C,[i(`img`,{src:x,alt:e.$t(`subscription.comfyCloudLogo`),class:`h-3/4 max-h-10 w-auto`},null,8,w)])}var T=g(S,[[`render`,_sfc_render]]),E={class:`mx-auto flex h-[5%] max-h-[60px] w-5/6 items-start gap-2.5`},D={href:`https://www.comfy.org/terms-of-service`,target:`_blank`,class:`cursor-pointer text-sm text-gray-600 no-underline`},O={href:`https://www.comfy.org/privacy-policy`,target:`_blank`,class:`cursor-pointer text-sm text-gray-600 no-underline`},k={href:`https://support.comfy.org`,class:`cursor-pointer text-sm text-gray-600 no-underline`,target:`_blank`,rel:`noopener noreferrer`},A=s({__name:`CloudTemplateFooter`,setup(e){let{t:a}=p();return(e,s)=>(t(),n(`footer`,E,[i(`a`,D,r(o(a)(`auth.login.termsLink`)),1),i(`a`,O,r(o(a)(`auth.login.privacyLink`)),1),i(`a`,k,r(o(a)(`cloudFooter_needHelp`)),1)]))}}),j={class:`flex`},M={class:`relative hidden flex-1 overflow-hidden bg-black lg:block`},N=[`poster`],P=[`src`],F={class:`absolute inset-0 flex items-center justify-center text-center text-white`},I={class:`font-abcrom hero-title font-black uppercase italic`},L={class:`m-2 text-center text-xl text-white`},R={class:`m-0 text-center text-xl text-white`},z={class:`absolute inset-0 flex flex-col justify-end px-14 pb-[64px]`},B={class:`flex items-center justify-end`},V={class:`flex items-center gap-3`},H={class:`text-md text-white`},U=s({__name:`CloudTemplate`,setup(e){let handleDownloadClick=()=>{window.open(`https://www.comfy.org/download`,`_blank`)};return(e,s)=>(t(),n(`div`,j,[a(v,{dark:``,class:`flex-1`},{header:l(()=>[a(T)]),footer:l(()=>[a(A)]),default:l(()=>[u(e.$slots,`default`)]),_:3}),i(`div`,M,[i(`video`,{class:`absolute inset-0 h-full w-full object-cover`,autoplay:``,muted:``,loop:``,playsinline:``,poster:o(y)},[i(`source`,{src:o(b),type:`video/mp4`},null,8,P)],8,N),s[0]||=i(`div`,{class:`absolute inset-0 h-full w-full bg-black/30`},null,-1),i(`div`,F,[i(`div`,null,[i(`h1`,I,r(o(m)(`cloudStart_title`)),1),i(`p`,L,r(o(m)(`cloudStart_desc`)),1),i(`p`,R,r(o(m)(`cloudStart_explain`)),1)])]),i(`div`,z,[i(`div`,B,[i(`div`,V,[i(`p`,H,r(o(m)(`cloudStart_wantToRun`)),1),a(h,{type:`button`,class:`h-10 bg-black font-bold text-white`,variant:`secondary`,onClick:handleDownloadClick},{default:l(()=>[c(r(o(m)(`cloudStart_download`)),1)]),_:1})])])])])]))}}),W=s({__name:`CloudLayoutView`,setup(e){return(e,r)=>(t(),n(f,null,[a(U,null,{default:l(()=>[a(o(d))]),_:1}),a(_)],64))}});export{W as default};
//# sourceMappingURL=CloudLayoutView-9BGA-hGD.js.map