import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{r as t,t as n}from"./types-0oh-UGWL.js";const r={DISTRIBUTION:`tf_42243568391700`,ANONYMOUS_EMAIL:`tf_anonymous_requester_email`,EMAIL:`tf_40029135130388`,USER_ID:`tf_42515251051412`};function getDistribution(){return n?`ccloud`:`oss-nightly`}var i=`https://support.comfy.org/hc/en-us/requests/new`;function buildSupportUrl(e){let t=new URLSearchParams({[r.DISTRIBUTION]:getDistribution()});return e?.userEmail&&(t.append(r.ANONYMOUS_EMAIL,e.userEmail),t.append(r.EMAIL,e.userEmail)),e?.userId&&t.append(r.USER_ID,e.userId),`${i}?${t.toString()}`}export{buildSupportUrl as n,getDistribution as r,r as t};
//# sourceMappingURL=config-C9O0f1Fo.js.map