import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{a as t}from"./dialogService-BC0EXJA5.js";function formatTime(e){return isNaN(e)||e===0?`0:00`:`${Math.floor(e/60)}:${Math.floor(e%60).toString().padStart(2,`0`)}`}function getResourceURL(e,n,r=`input`){return`/view?${[`filename=`+encodeURIComponent(n),`type=`+r,`subfolder=`+e,t.getRandParam().substring(1)].join(`&`)}`}function splitFilePath(e){let t=e.lastIndexOf(`/`);return t===-1?[``,e]:[e.substring(0,t),e.substring(t+1)]}export{getResourceURL as n,splitFilePath as r,formatTime as t};
//# sourceMappingURL=audioUtils-BWniSitz.js.map