import{r as __name}from"./rolldown-runtime-DCMCV6zW.js";function getWidgetStep(e){return e.step2||(e.step||10)*.1}function evaluateInput(input){if(/^[\d\s.()*+/-]+$/.test(input))try{input=eval(input)}catch{}const newValue=Number(input);if(!isNaN(newValue))return newValue}export{getWidgetStep as n,evaluateInput as t};
//# sourceMappingURL=widget-B3lMdpiR.js.map