[data-v-89909ff5] .p-inputtext{box-shadow:none!important;background:#2d2e32!important;border:none!important}[data-v-89909ff5] .p-password input{box-shadow:none!important;border:none!important}[data-v-89909ff5] .p-checkbox-checked .p-checkbox-box{background-color:#f0ff41!important;border-color:#f0ff41!important}
