import"./vendor-primevue-7po8Zk9v.js";import"./vendor-other-CrvBxfcV.js";import"./types-0oh-UGWL.js";import"./remoteConfig-CNDr9CtS.js";import"./api-3C7_IVZO.js";import"./colorUtil-C83P1Arv.js";import"./i18n-DjEVEIh2.js";import{t as e}from"./refreshRemoteConfig-BG1v6jUH.js";export{e as refreshRemoteConfig};