import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-7po8Zk9v.js";import{$ as t,A as n,Bt as r,D as i,E as a,F as o,L as s,P as c,ht as l}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import"./i18n-DjEVEIh2.js";import"./vendor-reka-ui-Bm3o_ZTf.js";import{t as u}from"./Button-mG8zDgxj.js";import{t as d}from"./useCopyToClipboard-CUuoo5Dm.js";var f={class:`flex w-full items-center justify-between px-3 pb-4`},p={class:`flex w-full items-start justify-end gap-2 pr-1`},m=s({__name:`ImportFailedNodeFooter`,props:{conflictedPackages:{default:()=>[]}},setup(e){let{copyToClipboard:s}=d(),m=a(()=>{let t=[];return e.conflictedPackages.forEach(e=>{let n=e.conflicts.find(e=>e.type===`import_failed`);n?.required_value&&t.push(n.required_value)}),t.join(`

`)}),handleCopyError=()=>{s(m.value)};return(e,a)=>(t(),n(`div`,f,[i(`div`,p,[o(u,{variant:`secondary`,onClick:handleCopyError},{default:l(()=>[c(r(e.$t(`importFailed.copyError`)),1)]),_:1})])]))}});export{m as default};
//# sourceMappingURL=ImportFailedNodeFooter-JXm1fHzA.js.map