import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import"./vendor-primevue-7po8Zk9v.js";import"./vendor-firebase-CdLSXhbt.js";import{$ as t,A as n,Bt as r,D as i,Et as a,F as o,L as s,Lt as c,P as l,ht as u,k as d,o as f,tt as p,x as m}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import"./types-0oh-UGWL.js";import"./remoteConfig-CNDr9CtS.js";import"./api-3C7_IVZO.js";import"./colorUtil-C83P1Arv.js";import"./i18n-DjEVEIh2.js";import"./useErrorHandling-CBX3YQ5l.js";import"./vendor-reka-ui-Bm3o_ZTf.js";import{t as h}from"./Button-mG8zDgxj.js";import{wn as g}from"./dialogService-BC0EXJA5.js";import"./systemStatsStore-gvlzOl4W.js";import"./dialogStore-BbHfkjRE.js";import"./useCopyToClipboard-CUuoo5Dm.js";import"./vendor-tiptap-DsZVujQD.js";import"./vendor-markdown-yjaB1jgA.js";import"./markdownRendererUtil-D5cHPoK2.js";var _={class:`flex h-full items-center justify-center p-6`},v={class:`max-w-[100vw] text-center lg:w-[500px]`},y={class:`mb-3 text-xl text-text-primary`},b={class:`mb-5 text-muted`},x={class:`mb-4 rounded bg-secondary-background px-3 py-2 text-left`},S={class:`mb-2 text-sm font-semibold text-text-primary`},C={class:`space-y-1.5 text-sm text-muted`},w={key:0,class:`mb-4 text-left`},T={key:0,class:`mt-2 rounded border-muted-background border p-4 font-mono text-xs text-muted-foreground break-all`},E={class:`mb-5 text-center text-sm text-gray-600`},D={href:`https://support.comfy.org`,class:`cursor-pointer text-blue-400 no-underline`,target:`_blank`,rel:`noopener noreferrer`},O={class:`flex flex-col gap-3`},k=s({__name:`CloudAuthTimeoutView`,props:{errorMessage:{}},setup(e){let s=f(),{logout:k}=g(),A=a(!1),handleRestart=async()=>{await k(),await s.replace({name:`cloud-login`})};return(e,a)=>(t(),n(`div`,_,[i(`div`,v,[i(`h2`,y,r(e.$t(`cloudOnboarding.authTimeout.title`)),1),i(`p`,b,r(e.$t(`cloudOnboarding.authTimeout.message`)),1),i(`div`,x,[i(`h3`,S,r(e.$t(`cloudOnboarding.authTimeout.troubleshooting`)),1),i(`ul`,C,[(t(!0),n(m,null,p(e.$tm(`cloudOnboarding.authTimeout.causes`),(e,o)=>(t(),n(`li`,{key:o,class:`flex gap-2`},[a[1]||=i(`span`,null,`•`,-1),i(`span`,null,r(e),1)]))),128))])]),e.errorMessage?(t(),n(`div`,w,[i(`button`,{class:`flex w-full items-center justify-between rounded bg-secondary-background px-4 py-2 text-sm text-text-secondary transition-colors hover:bg-secondary-background-hover border-0`,onClick:a[0]||=e=>A.value=!A.value},[i(`span`,null,r(e.$t(`cloudOnboarding.authTimeout.technicalDetails`)),1),i(`i`,{class:c([`pi`,A.value?`pi-chevron-up`:`pi-chevron-down`])},null,2)]),A.value?(t(),n(`div`,T,r(e.errorMessage),1)):d(``,!0)])):d(``,!0),i(`p`,E,[l(r(e.$t(`cloudOnboarding.authTimeout.helpText`))+` `,1),i(`a`,D,r(e.$t(`cloudOnboarding.authTimeout.supportLink`)),1),a[2]||=l(`. `)]),i(`div`,O,[o(h,{class:`w-full`,onClick:handleRestart},{default:u(()=>[l(r(e.$t(`cloudOnboarding.authTimeout.restart`)),1)]),_:1})])])]))}});export{k as default};
//# sourceMappingURL=CloudAuthTimeoutView-DtMbu7fe.js.map