import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{P as t}from"./vendor-primevue-7po8Zk9v.js";import"./vendor-firebase-CdLSXhbt.js";import{$ as n,A as r,Bt as i,D as a,E as o,F as s,Ft as c,L as l,Lt as u,P as d,ht as f,k as p,lt as m,tt as h,x as g}from"./vendor-vue-core-D3IvUUeM.js";import"./vendor-other-CrvBxfcV.js";import"./types-0oh-UGWL.js";import"./remoteConfig-CNDr9CtS.js";import"./api-3C7_IVZO.js";import"./colorUtil-C83P1Arv.js";import"./i18n-DjEVEIh2.js";import"./useErrorHandling-CBX3YQ5l.js";import"./vendor-reka-ui-Bm3o_ZTf.js";import{t as _}from"./Button-mG8zDgxj.js";import{r as v}from"./dialogService-BC0EXJA5.js";import"./systemStatsStore-gvlzOl4W.js";import"./dialogStore-BbHfkjRE.js";import"./useCopyToClipboard-CUuoo5Dm.js";import"./vendor-tiptap-DsZVujQD.js";import"./vendor-markdown-yjaB1jgA.js";import"./markdownRendererUtil-D5cHPoK2.js";var y={class:`w-113 max-w-md p-4 space-y-4`},b={class:`text-sm text-muted-foreground leading-tight`},x={class:`text-base-foreground font-medium`},S={class:`space-y-2`},C={class:`flex items-center gap-2 flex-1 min-w-0 text-wrap`},w={class:`flex items-center justify-center w-8 h-8 rounded-lg flex-shrink-0 bg-secondary-background border border-border-subtle`},T={key:1,class:`text-xs font-normal text-base-foreground`},E={class:`flex flex-col gap-0.5 min-w-0 flex-1`},D={class:`text-sm font-normal text-base-foreground leading-tight`},O={class:`text-sm font-normal text-muted-foreground leading-tight`},k=l({__name:`ValueControlPopover`,props:{modelValue:{},modelModifiers:{}},emits:[`update:modelValue`],setup(e){let l=v(),k=[{mode:`fixed`,icon:`icon-[lucide--pencil-off]`,title:`fixed`,description:`fixedDesc`},{mode:`increment`,text:`+1`,title:`increment`,description:`incrementDesc`},{mode:`decrement`,text:`-1`,title:`decrement`,description:`decrementDesc`},{mode:`randomize`,icon:`icon-[lucide--shuffle]`,title:`randomize`,description:`randomizeDesc`}],A=o(()=>l.get(`Comfy.WidgetControlMode`)),j=m(e,`modelValue`);return(e,o)=>(n(),r(`div`,y,[a(`div`,b,[d(i(e.$t(`widgets.valueControl.header.prefix`))+` `,1),a(`span`,x,i(A.value===`before`?e.$t(`widgets.valueControl.header.before`):e.$t(`widgets.valueControl.header.after`)),1),d(` `+i(e.$t(`widgets.valueControl.header.postfix`)),1)]),a(`div`,S,[(n(),r(g,null,h(k,l=>s(_,{key:l.mode,as:`label`,variant:`textonly`,size:`lg`,class:`flex w-full h-[unset] text-left items-center justify-between py-2 gap-7`,for:l.mode},{default:f(()=>[a(`div`,C,[a(`div`,w,[l.icon?(n(),r(`i`,{key:0,class:u([l.icon,`text-base text-base-foreground`])},null,2)):p(``,!0),l.text?(n(),r(`span`,T,i(l.text),1)):p(``,!0)]),a(`div`,E,[a(`div`,D,[a(`span`,null,i(e.$t(`widgets.valueControl.${l.title}`)),1)]),a(`div`,O,i(e.$t(`widgets.valueControl.${l.description}`)),1)])]),s(c(t),{modelValue:j.value,"onUpdate:modelValue":o[0]||=e=>j.value=e,class:`shrink`,"input-id":l.mode,value:l.mode},null,8,[`modelValue`,`input-id`,`value`])]),_:2},1032,[`for`])),64))])]))}});export{k as default};
//# sourceMappingURL=ValueControlPopover-BJ0z5W84.js.map