import{r as e}from"./rolldown-runtime-DCMCV6zW.js";import{$ as t,A as n,Bt as r,D as i,E as a,Et as o,L as s}from"./vendor-vue-core-D3IvUUeM.js";var c={class:`relative size-full overflow-hidden rounded`},l=[`src`,`alt`],u={key:1,class:`flex size-full flex-col items-center justify-center gap-2 bg-modal-card-placeholder-background transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`},d={class:`text-sm text-base-foreground`},f=s({__name:`Media3DTop`,props:{asset:{}},setup(e){let s=o(!1),f=a(()=>e.asset?.src?e.asset.src.replace(/([?&]filename=)([^&]*)/,`$1$2.png`):``);return(e,a)=>(t(),n(`div`,c,[s.value?(t(),n(`div`,u,[a[1]||=i(`i`,{class:`icon-[lucide--box] text-3xl text-muted-foreground`},null,-1),i(`span`,d,r(e.$t(`assetBrowser.media.threeDModelPlaceholder`)),1)])):(t(),n(`img`,{key:0,src:f.value,alt:e.asset?.name,class:`size-full object-contain transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`,onError:a[0]||=e=>s.value=!0},null,40,l))]))}});export{f as default};
//# sourceMappingURL=Media3DTop-q9LZQHlZ.js.map